@@ -8,26 +8,26 @@ ggplot(iris, aes(x=Petal.Length, y=Petal.Width, color=Species)) + geom_point() +
 
 ## ---- fig.show='hold'----------------------------------------------------
 library(plotluck)
-plotluck(Petal.Width~Petal.Length|Species, iris)
+plotluck(iris, Petal.Width~Petal.Length|Species)
 
 ## ---- fig.show='hold'----------------------------------------------------
 library(gapminder)
-plotluck(.~1, gapminder)
+plotluck(gapminder, .~1)
 
 ## ---- fig.show='hold', warning=FALSE-------------------------------------
 opts <- plotluck.options(verbose=TRUE)
-plotluck(lifeExp~., weights=pop, data=gapminder, opts=opts)
+plotluck(gapminder, lifeExp~., weights=pop, opts=opts)
 
 ## ---- fig.show='hold', warning=FALSE-------------------------------------
-plotluck(lifeExp~continent, weights=pop, data=gapminder, opts=opts)
+plotluck(gapminder, lifeExp~continent, weights=pop, opts=opts)
 
 ## ---- fig.show='hold'----------------------------------------------------
-plotluck(lifeExp~continent+country, weights=pop, data=gapminder, opts=opts)
+plotluck(gapminder, lifeExp~continent+country, weights=pop, opts=opts)
 
 ## ---- fig.show='hold'----------------------------------------------------
-plotluck(lifeExp~year|continent, weights=pop, data=gapminder, opts=opts)
+plotluck(gapminder, lifeExp~year|continent, weights=pop, opts=opts)
 
 ## ---- fig.show='hold'----------------------------------------------------
 set.seed(6)
-sample.plotluck(gapminder,weights=pop,opts)
+sample.plotluck(gapminder, weights=pop, opts)
 
